The following tasks implement timing paradigms:

- [IntervalDiscrimination](../envs.md#neurogym.envs.native.intervaldiscrimination.IntervalDiscrimination)
- [MotorTiming](../envs.md#neurogym.envs.native.readysetgo.MotorTiming)
- [OneTwoThreeGo](../envs.md#neurogym.envs.native.readysetgo.OneTwoThreeGo)
- [ReadySetGo](../envs.md#neurogym.envs.native.readysetgo.ReadySetGo)
